Kindhearted police with holiday spirit | Dallas Morning News
Description: On Saturday, I went to volunteer at the Operation Care International’s Christmas Party For Jesus at the Kay Bailey Hutchison Convention Center, and being directionally impaired, I got lost and…

# Kindhearted police with holiday spirit

###### Letters to the Editor Email comments@dallasnews.com

Published: December 24, 2014 12:02 pm

On Saturday, I went to volunteer at the Operation Care International’s Christmas Party For Jesus at the Kay Bailey Hutchison Convention Center, and being directionally impaired, I got lost and had no idea where to park.

Related

- Limerick: Bells toll for Dallas
- Message of the season

I saw two female Dallas police officers and rolled down my window to ask about parking. Upon rolling down my window, the antler on my window fell off. Not wanting to backtrack and tie up traffic, I drove off leaving the antler on the street. I found the parking meter lot that the officer had given me directions to, but then realized I had no change.

I was standing by the meter figuring out how to pay when I hear someone saying, “Hey, you lost your antler.” I turned around, and the female officer was in her squad car holding out the antler that had fallen off my window. I went over and got my antler, explaining that I was figuring out how to pay for parking because I had no change. The officer said they had just announced that they would not be giving out parking-meter ticket violations that day during the event hours. I’m thankful to our Dallas Police Department for all they do.

Kim Gump, Dallas

### Top Picks

Comments

To post a comment, log into your chosen social network and then add your comment below. Your comments are subject to our Terms of Service and the privacy policy and terms of service of your social network. If you do not want to comment with a social network, please consider writing a letter to the editor.

Archives
About this blog
About This Blog

We welcome and read all letters from readers, and we salute those people willing to sign their names to their opinions. The letters chosen for publication are a representative sampling of the opinions shared with us. We include all published letters on this blog and encourage readers to engage in a civil debate: Attack ideas, if you like, but not one another.

Resources

Send a letter

Send a video letter

Letter writing tips

Ad:Right
Ad: Position1
Ad: Position2
Ad: Right2
Categories
Mobile/Newsletters
Ad: Position3
Ad: Position4